==> geoview-0.0.6.tar.gz: geoview-0.0.6/README.md <==
## GeoView

Extract information from geoip and geosite files from Project X and Sing-box.

### Usage

```
Usage:
  -action string
        action: extract | convert (default "extract")
  -append
        append to existing file instead of overwriting
  -input string
        datafile
  -ipv4
        enable ipv4 output (default true)
  -ipv6
        enable ipv6 output (default true)
  -list string
        comma separated site or geo list, e.g. "cn,jp" or "youtube,google"
  -output string
        output to file, leave empty to print to console
  -regex
        allow regex rules in the geosite result
  -type string
        datafile type: geoip | geosite (default "geoip")
```

### Examples

#### Extract IP ranges of China and Japan from geoip.dat

```bash
./geoview -type geoip -input geoip.dat -list cn,jp -output cn_jp.txt
```

### Extract domain list of gfw from geosite.dat

```bash
./geoview -type geosite -input geosite.dat -list gfw -output gfw.txt
```

### Extract domain list of medium and convert into sing-box ruleset JSON

```bash
./geoview -type geosite -action convert -input geosite.dat -list medium -output medium.json
```

### Extract domain list of medium and convert into sing-box ruleset binary
```bash
./geoview -type geosite -action convert -input geosite.dat -list medium -output medium.srs
```

* Regex rules of geosite are ignored by default.

* When using `-append=true` to ruleset and the output format is JSON, existing rules will be kept and new rules will be appended.

* When converting geo files to ruleset, the output format is determined by file extensions. Without specifying the output file extension, the output format is always JSON.

* Binary ruleset conversion doesn't support appending, it always creates a new file.


## Compile for OpenWrt

Download the latest Openwrt source and clone this repository to the package directory.

```bash
git clone https://github.com/snowie2000/geoview.git package/geoview
```

Follow the steps below to compile the package.

```bash
./scripts/feeds update -a
./scripts/feeds install -a

make menuconfig

Network  ---> Web Servers/Proxies  ---> <*> geoview

make package/geoview/{clean,compile} V=s
```

To compile the golang projects under `Linux/arm64`, you need to manually install golang and set external golang environment in the `make menuconfig` menu.

-----

## Credit

Great thanks to project [geoip](https://github.com/Loyalsoldier/geoip) and [geo](https://github.com/MetaCubeX/geo)

==> geoview-0.0.7.tar.gz: geoview-0.0.7/README.md <==
## GeoView

Extract information from geoip and geosite files from Project X and Sing-box.

### Usage

```
Usage:
  -action string
        action: extract | convert | lookup (default "extract")
  -append
        append to existing file instead of overwriting
  -input string
        datafile
  -ipv4
        enable ipv4 output (default true)
  -ipv6
        enable ipv6 output (default true)
  -list string
        comma separated site or geo list, e.g. "cn,jp" or "youtube,google"
  -lowmem
        low memory mode, reduce memory cost by partial file reading
  -output string
        output to file, leave empty to print to console
  -regex
        allow regex rules in the geosite result
  -type string
        datafile type: geoip | geosite (default "geoip")
  -value string
        ip or domain to lookup, required only for lookup action
```

### Examples

#### Extract IP ranges of China and Japan from geoip.dat

```bash
./geoview -type geoip -input geoip.dat -list cn,jp -output cn_jp.txt
```

### Extract domain list of gfw from geosite.dat

```bash
./geoview -type geosite -input geosite.dat -list gfw -output gfw.txt
```

### Extract domain list of medium and convert into sing-box ruleset JSON

```bash
./geoview -type geosite -action convert -input geosite.dat -list medium -output medium.json
```

### Extract domain list of medium and convert into sing-box ruleset binary
```bash
./geoview -type geosite -action convert -input geosite.dat -list medium -output medium.srs
```

* Regex rules of geosite are ignored by default.

* When using `-append=true` to ruleset and the output format is JSON, existing rules will be kept and new rules will be appended.

* When converting geo files to ruleset, the output format is determined by file extensions. Without specifying the output file extension, the output format is always JSON.

* Binary ruleset conversion doesn't support appending, it always creates a new file.

### Low memory mode
By adding `-lowmem` to the command, the program will read the file partially to reduce memory usage. This is useful when execute on devices with limited memory.

## Compile for OpenWrt

Download the latest Openwrt source and clone this repository to the package directory.

```bash
git clone https://github.com/snowie2000/geoview.git package/geoview
```

Follow the steps below to compile the package.

```bash
./scripts/feeds update -a
./scripts/feeds install -a

make menuconfig

Network  ---> Web Servers/Proxies  ---> <*> geoview

make package/geoview/{clean,compile} V=s
```

To compile the golang projects under `Linux/arm64`, you need to manually install golang and set external golang environment in the `make menuconfig` menu.

-----

## Credit

Great thanks to project [geoip](https://github.com/Loyalsoldier/geoip) and [geo](https://github.com/MetaCubeX/geo)
